﻿using Microsoft.Data.SqlClient;

var connString = $"Data Source=localhost\\SQLEXPRESS;Initial Catalog=AdventureWorks2022;TrustServerCertificate=true; Integrated Security=True;";
var conn = new SQLDeleter.Connection(connString);

var obj = conn.LoadLatestInserted();

if(obj == null)
{
    obj = conn.GetSyncWithDB(); // can be quite slow if it is a big DB
    conn.Save(obj, "1.0"); // null is allowed as a version, we save so we don't need to sync next time we start program
}

var sqlQuery = "delete from [Person].[Person] where BusinessEntityID = 1;";

var allVersions = conn.GetSortedVersions();
Console.WriteLine("Total amount of saved down versions: " + allVersions.Count);

if (allVersions.Count == 1)
{
    using (var connection = new SqlConnection(connString))
    {
        connection.Open();

        // SQL query to create the new table [Person].[Test]
        string createTableQuery = @"
            CREATE TABLE [Person].[Test] (
                Id INT IDENTITY(1,1) PRIMARY KEY,
                PersonBusinessEntityID INT NULL,
                CONSTRAINT FK_Person_Test_BusinessEntityID FOREIGN KEY (PersonBusinessEntityID) 
                    REFERENCES [Person].[Person](BusinessEntityID)
            );
        ";

        // Execute the table creation query
        using (var command = new SqlCommand(createTableQuery, connection))
        {
            command.ExecuteNonQuery();
            Console.WriteLine("[Person].[Test] table created successfully.");
        }

        obj = conn.GetSyncWithDB(); // can be quite slow if it is a big DB
        conn.Save(obj, "2.0"); // null is allowed as a version, we save so we don't need to sync next time we start program
        allVersions = conn.GetSortedVersions();
    }
}

var version1 = conn.Load(allVersions[0]);
var version2 = conn.Load(allVersions[1]);

if(version1.CompareResult(version2, sqlQuery))
{
    Console.WriteLine("Both versions give same result");
}
else
{
    Console.WriteLine($"The linking from [Person].[Person] has changed from version {allVersions[0]} to version {allVersions[1]}");
} 

var result = obj.Generate(sqlQuery);
Console.WriteLine("Result from latest added version: \n" + result);
